@@ -3,10 +3,11 @@ from __future__ import annotations
 
 from typing import ClassVar
 
-from pyplumio.devices import Device, DeviceTypes
+from pyplumio.const import AddressTypes
+from pyplumio.devices import Device
 
 
 class EcoSTER(Device):
     """Represents ecoSTER thermostat."""
 
-    address: ClassVar[int] = DeviceTypes.ECOSTER
+    address: ClassVar[int] = AddressTypes.ECOSTER
