@@ -3,9 +3,9 @@ from __future__ import annotations
 
 from typing import ClassVar, Optional
 
-from pyplumio.const import ATTR_EXTRA, ATTR_NAME, ATTR_VALUE
+from pyplumio.const import ATTR_EXTRA, ATTR_NAME, ATTR_VALUE, FrameTypes
 from pyplumio.exceptions import FrameDataError
-from pyplumio.frames import FrameTypes, Request, Response
+from pyplumio.frames import Request, Response
 from pyplumio.frames.responses import DeviceAvailableResponse, ProgramVersionResponse
 from pyplumio.helpers.typing import DeviceDataType, MessageType
 from pyplumio.structures.schedules import SchedulesStructure
@@ -61,6 +61,13 @@ class MixerParametersRequest(Request):
 
     frame_type: ClassVar[int] = FrameTypes.REQUEST_MIXER_PARAMETERS
 
+    def create_message(self, data: DeviceDataType) -> MessageType:
+        """Create frame message."""
+        message = bytearray()
+        message.append(255)  # Number of parameters.
+        message.append(0)  # Index of the first parameter.
+        return message
+
 
 class DataSchemaRequest(Request):
     """Represents data schema request."""
