@@ -15,6 +15,6 @@ def factory(class_path: str, **kwargs):
             importlib.import_module("." + module_name, "pyplumio"), class_name
         )
         return cls(**kwargs)
-    except Exception as e:
+    except Exception:
         _LOGGER.error("Failed to load module (%s)", class_path)
-        raise ImportError(f"Failed to load module ({class_path})") from e
+        raise
