@@ -1,12 +1,12 @@
 """Contains reader and writer classes."""
 from __future__ import annotations
 
-import asyncio
+from asyncio import IncompleteReadError, StreamReader, StreamWriter
 import logging
 from typing import Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.const import ADDR_BROADCAST, ADDR_ECONET
+from pyplumio.const import AddressTypes
 from pyplumio.exceptions import ChecksumError, ReadError
 from pyplumio.frames import FRAME_START, HEADER_SIZE, Frame, get_frame_handler
 from pyplumio.helpers.factory import factory
@@ -24,9 +24,9 @@ _LOGGER = logging.getLogger(__name__)
 class FrameWriter:
     """Represents frame writer."""
 
-    _writer: asyncio.StreamWriter
+    _writer: StreamWriter
 
-    def __init__(self, writer: asyncio.StreamWriter):
+    def __init__(self, writer: StreamWriter):
         """Initialize new Frame Writer object."""
         self._writer = writer
 
@@ -37,7 +37,6 @@ class FrameWriter:
         self._writer.write(frame.bytes)
         await self._writer.drain()
         _LOGGER.debug("Sent frame: %s", frame)
-        await asyncio.sleep(0.1)
 
     @timeout(WRITER_TIMEOUT)
     async def close(self) -> None:
@@ -49,9 +48,9 @@ class FrameWriter:
 class FrameReader:
     """Represents frame reader."""
 
-    _reader: asyncio.StreamReader
+    _reader: StreamReader
 
-    def __init__(self, reader: asyncio.StreamReader):
+    def __init__(self, reader: StreamReader):
         """Initialize new Frame Reader object."""
         self._reader = reader
 
@@ -74,7 +73,14 @@ class FrameReader:
                 econet_version,
             ] = util.unpack_header(buffer)
 
-            return buffer, length, recipient, sender, sender_type, econet_version
+            return (
+                buffer,
+                length,
+                recipient,
+                sender,
+                sender_type,
+                econet_version,
+            )
 
         raise OSError("No data can be read, RS485 connection broken")
 
@@ -90,7 +96,7 @@ class FrameReader:
             econet_version,
         ) = await self._read_header()
 
-        if recipient not in (ADDR_ECONET, ADDR_BROADCAST):
+        if recipient not in (AddressTypes.ECONET, AddressTypes.BROADCAST):
             return None
 
         if length > MAX_FRAME_LENGTH or length < MIN_FRAME_LENGTH:
@@ -98,7 +104,7 @@ class FrameReader:
 
         try:
             payload = await self._reader.readexactly(length - HEADER_SIZE)
-        except asyncio.IncompleteReadError as e:
+        except IncompleteReadError as e:
             raise ReadError(
                 "Got an incomplete frame while trying to read "
                 + f"'{length - HEADER_SIZE}' bytes"
