@@ -4,7 +4,7 @@ from __future__ import annotations
 import struct
 from typing import Final, Optional, Tuple
 
-from pyplumio.const import ATTR_MODULES
+from pyplumio.const import ATTR_MODULES, BYTE_UNDEFINED
 from pyplumio.helpers.product_info import ConnectedModules
 from pyplumio.helpers.typing import DeviceDataType
 from pyplumio.structures import StructureDecoder, make_device_data
@@ -29,7 +29,7 @@ def _get_module_version(
     module_name: str, message: bytearray, offset: int = 0
 ) -> Tuple[Optional[str], int]:
     """Get module version from a message."""
-    if message[offset] == 0xFF:
+    if message[offset] == BYTE_UNDEFINED:
         return None, (offset + 1)
 
     version_data = struct.unpack("<BBB", message[offset : offset + 3])
